@@ -51,7 +51,7 @@ ToSigned(uint64 u) {
   return static_cast<int64>(u - std::numeric_limits<int64>::min()) + std::numeric_limits<int64>::min();
 }
 
-}
+} // namespace
 
 START_LIBEBML_NAMESPACE
 
@@ -65,13 +65,6 @@ EbmlSInteger::EbmlSInteger(int64 aDefaultValue)
   SetDefaultIsSet();
 }
 
-EbmlSInteger::EbmlSInteger(const EbmlSInteger & ElementToClone)
-  :EbmlElement(ElementToClone)
-  ,Value(ElementToClone.Value)
-  ,DefaultValue(ElementToClone.DefaultValue)
-{
-}
-
 EbmlSInteger::operator int8() const {return  int8(Value);}
 EbmlSInteger::operator int16() const {return int16(Value);}
 EbmlSInteger::operator int32() const {return int32(Value);}
@@ -140,22 +133,28 @@ uint64 EbmlSInteger::UpdateSize(bool bWithDefault, bool /* bForceRender */)
 
 filepos_t EbmlSInteger::ReadData(IOCallback & input, ScopeMode ReadFully)
 {
-  if (ReadFully != SCOPE_NO_DATA) {
-    binary Buffer[8];
-    input.readFully(Buffer, GetSize());
+  if (ReadFully == SCOPE_NO_DATA)
+    return GetSize();
 
-    uint64 TempValue = Buffer[0] & 0x80 ? std::numeric_limits<uint64>::max() : 0;
-
-    for (unsigned int i=0; i<GetSize(); i++) {
-      TempValue <<= 8;
-      TempValue |= Buffer[i];
-    }
-
-    Value = ToSigned(TempValue);
-
-    SetValueIsSet();
+  if (GetSize() > 8) {
+    // impossible to read, skip it
+    input.setFilePointer(GetSize(), seek_current);
+    return GetSize();
   }
 
+  binary Buffer[8];
+  input.readFully(Buffer, GetSize());
+
+  uint64 TempValue = Buffer[0] & 0x80 ? std::numeric_limits<uint64>::max() : 0;
+
+  for (unsigned int i=0; i<GetSize(); i++) {
+    TempValue <<= 8;
+    TempValue |= Buffer[i];
+  }
+
+  Value = ToSigned(TempValue);
+
+  SetValueIsSet();
   return GetSize();
 }
 
@@ -163,8 +162,8 @@ bool EbmlSInteger::IsSmallerThan(const EbmlElement *Cmp) const
 {
   if (EbmlId(*this) == EbmlId(*Cmp))
     return this->Value < static_cast<const EbmlSInteger *>(Cmp)->Value;
-  else
-    return false;
+
+  return false;
 }
 
 END_LIBEBML_NAMESPACE
